@@ -2,7 +2,7 @@
 A collection of functions and objects for creating or placing inset axes.
 """
 
-from matplotlib import cbook, docstring
+from matplotlib import _api, _docstring
 from matplotlib.offsetbox import AnchoredOffsetbox
 from matplotlib.patches import Patch, Rectangle
 from matplotlib.path import Path
@@ -13,8 +13,8 @@ from . import axes_size as Size
 from .parasite_axes import HostAxes
 
 
-class InsetPosition(object):
-    @docstring.dedent_interpd
+class InsetPosition:
+    @_docstring.dedent_interpd
     def __init__(self, parent, lbwh):
         """
         An object for positioning an inset axes.
@@ -24,7 +24,7 @@ class InsetPosition(object):
 
         Parameters
         ----------
-        parent : `matplotlib.axes.Axes`
+        parent : `~matplotlib.axes.Axes`
             Axes to use for normalizing coordinates.
 
         lbwh : iterable of four floats
@@ -38,12 +38,12 @@ class InsetPosition(object):
         Examples
         --------
         The following bounds the inset axes to a box with 20%% of the parent
-        axes's height and 40%% of the width. The size of the axes specified
+        axes height and 40%% of the width. The size of the axes specified
         ([0, 0, 1, 1]) ensures that the axes completely fills the bounding box:
 
         >>> parent_axes = plt.gca()
         >>> ax_ins = plt.axes([0, 0, 1, 1])
-        >>> ip = InsetPosition(ax, [0.5, 0.1, 0.4, 0.2])
+        >>> ip = InsetPosition(parent_axes, [0.5, 0.1, 0.4, 0.2])
         >>> ax_ins.set_axes_locator(ip)
         """
         self.parent = parent
@@ -69,19 +69,14 @@ class AnchoredLocatorBase(AnchoredOffsetbox):
         raise RuntimeError("No draw method should be called")
 
     def __call__(self, ax, renderer):
+        if renderer is None:
+            renderer = ax.figure._get_renderer()
         self.axes = ax
-
-        fontsize = renderer.points_to_pixels(self.prop.get_size_in_points())
-        self._update_offset_func(renderer, fontsize)
-
-        width, height, xdescent, ydescent = self.get_extent(renderer)
-
-        px, py = self.get_offset(width, height, 0, 0, renderer)
-        bbox_canvas = Bbox.from_bounds(px, py, width, height)
-        tr = ax.figure.transFigure.inverted()
-        bb = TransformedBbox(bbox_canvas, tr)
-
-        return bb
+        bbox = self.get_window_extent(renderer)
+        px, py = self.get_offset(bbox.width, bbox.height, 0, 0, renderer)
+        bbox_canvas = Bbox.from_bounds(px, py, bbox.width, bbox.height)
+        tr = ax.figure.transSubfigure.inverted()
+        return TransformedBbox(bbox_canvas, tr)
 
 
 class AnchoredSizeLocator(AnchoredLocatorBase):
@@ -95,22 +90,19 @@ class AnchoredSizeLocator(AnchoredLocatorBase):
         self.x_size = Size.from_any(x_size)
         self.y_size = Size.from_any(y_size)
 
-    def get_extent(self, renderer):
-        x, y, w, h = self.get_bbox_to_anchor().bounds
-
+    def get_bbox(self, renderer):
+        bbox = self.get_bbox_to_anchor()
         dpi = renderer.points_to_pixels(72.)
 
         r, a = self.x_size.get_size(renderer)
-        width = w * r + a * dpi
-
+        width = bbox.width * r + a * dpi
         r, a = self.y_size.get_size(renderer)
-        height = h * r + a * dpi
-        xd, yd = 0, 0
+        height = bbox.height * r + a * dpi
 
         fontsize = renderer.points_to_pixels(self.prop.get_size_in_points())
         pad = self.pad * fontsize
 
-        return width + 2 * pad, height + 2 * pad, xd + pad, yd + pad
+        return Bbox.from_bounds(0, 0, width, height).padded(pad)
 
 
 class AnchoredZoomLocator(AnchoredLocatorBase):
@@ -120,86 +112,57 @@ class AnchoredZoomLocator(AnchoredLocatorBase):
                  bbox_transform=None):
         self.parent_axes = parent_axes
         self.zoom = zoom
-
         if bbox_to_anchor is None:
             bbox_to_anchor = parent_axes.bbox
-
         super().__init__(
             bbox_to_anchor, None, loc, borderpad=borderpad,
             bbox_transform=bbox_transform)
 
-    def get_extent(self, renderer):
-        bb = TransformedBbox(self.axes.viewLim,
-                             self.parent_axes.transData)
-        x, y, w, h = bb.bounds
+    def get_bbox(self, renderer):
+        bb = self.parent_axes.transData.transform_bbox(self.axes.viewLim)
         fontsize = renderer.points_to_pixels(self.prop.get_size_in_points())
         pad = self.pad * fontsize
-        return (abs(w * self.zoom) + 2 * pad, abs(h * self.zoom) + 2 * pad,
-                pad, pad)
+        return (
+            Bbox.from_bounds(
+                0, 0, abs(bb.width * self.zoom), abs(bb.height * self.zoom))
+            .padded(pad))
 
 
 class BboxPatch(Patch):
-    @docstring.dedent_interpd
+    @_docstring.dedent_interpd
     def __init__(self, bbox, **kwargs):
         """
         Patch showing the shape bounded by a Bbox.
 
         Parameters
         ----------
-        bbox : `matplotlib.transforms.Bbox`
+        bbox : `~matplotlib.transforms.Bbox`
             Bbox to use for the extents of this patch.
 
         **kwargs
             Patch properties. Valid arguments include:
-            %(Patch)s
+
+            %(Patch:kwdoc)s
         """
         if "transform" in kwargs:
             raise ValueError("transform should not be set")
 
         kwargs["transform"] = IdentityTransform()
-        Patch.__init__(self, **kwargs)
+        super().__init__(**kwargs)
         self.bbox = bbox
 
     def get_path(self):
         # docstring inherited
         x0, y0, x1, y1 = self.bbox.extents
-        verts = [(x0, y0),
-                 (x1, y0),
-                 (x1, y1),
-                 (x0, y1),
-                 (x0, y0),
-                 (0, 0)]
-        codes = [Path.MOVETO,
-                 Path.LINETO,
-                 Path.LINETO,
-                 Path.LINETO,
-                 Path.LINETO,
-                 Path.CLOSEPOLY]
-        return Path(verts, codes)
+        return Path._create_closed([(x0, y0), (x1, y0), (x1, y1), (x0, y1)])
 
 
 class BboxConnector(Patch):
     @staticmethod
     def get_bbox_edge_pos(bbox, loc):
         """
-        Helper function to obtain the location of a corner of a bbox
-
-        Parameters
-        ----------
-        bbox : `matplotlib.transforms.Bbox`
-
-        loc : {1, 2, 3, 4}
-            Corner of *bbox*. Valid values are::
-
-                'upper right'  : 1,
-                'upper left'   : 2,
-                'lower left'   : 3,
-                'lower right'  : 4
-
-        Returns
-        -------
-        x, y : float
-            Coordinates of the corner specified by *loc*.
+        Return the ``(x, y)`` coordinates of corner *loc* of *bbox*; parameters
+        behave as documented for the `.BboxConnector` constructor.
         """
         x0, y0, x1, y1 = bbox.extents
         if loc == 1:
@@ -214,97 +177,54 @@ class BboxConnector(Patch):
     @staticmethod
     def connect_bbox(bbox1, bbox2, loc1, loc2=None):
         """
-        Helper function to obtain a Path from one bbox to another.
-
-        Parameters
-        ----------
-        bbox1, bbox2 : `matplotlib.transforms.Bbox`
-            Bounding boxes to connect.
-
-        loc1 : {1, 2, 3, 4}
-            Corner of *bbox1* to use. Valid values are::
-
-                'upper right'  : 1,
-                'upper left'   : 2,
-                'lower left'   : 3,
-                'lower right'  : 4
-
-        loc2 : {1, 2, 3, 4}, optional
-            Corner of *bbox2* to use. If None, defaults to *loc1*.
-            Valid values are::
-
-                'upper right'  : 1,
-                'upper left'   : 2,
-                'lower left'   : 3,
-                'lower right'  : 4
-
-        Returns
-        -------
-        path : `matplotlib.path.Path`
-            A line segment from the *loc1* corner of *bbox1* to the *loc2*
-            corner of *bbox2*.
+        Construct a `.Path` connecting corner *loc1* of *bbox1* to corner
+        *loc2* of *bbox2*, where parameters behave as documented as for the
+        `.BboxConnector` constructor.
         """
         if isinstance(bbox1, Rectangle):
-            transform = bbox1.get_transform()
-            bbox1 = Bbox.from_bounds(0, 0, 1, 1)
-            bbox1 = TransformedBbox(bbox1, transform)
-
+            bbox1 = TransformedBbox(Bbox.unit(), bbox1.get_transform())
         if isinstance(bbox2, Rectangle):
-            transform = bbox2.get_transform()
-            bbox2 = Bbox.from_bounds(0, 0, 1, 1)
-            bbox2 = TransformedBbox(bbox2, transform)
-
+            bbox2 = TransformedBbox(Bbox.unit(), bbox2.get_transform())
         if loc2 is None:
             loc2 = loc1
-
         x1, y1 = BboxConnector.get_bbox_edge_pos(bbox1, loc1)
         x2, y2 = BboxConnector.get_bbox_edge_pos(bbox2, loc2)
+        return Path([[x1, y1], [x2, y2]])
 
-        verts = [[x1, y1], [x2, y2]]
-        codes = [Path.MOVETO, Path.LINETO]
-
-        return Path(verts, codes)
-
-    @docstring.dedent_interpd
+    @_docstring.dedent_interpd
     def __init__(self, bbox1, bbox2, loc1, loc2=None, **kwargs):
         """
         Connect two bboxes with a straight line.
 
         Parameters
         ----------
-        bbox1, bbox2 : `matplotlib.transforms.Bbox`
+        bbox1, bbox2 : `~matplotlib.transforms.Bbox`
             Bounding boxes to connect.
 
-        loc1 : {1, 2, 3, 4}
-            Corner of *bbox1* to draw the line. Valid values are::
+        loc1, loc2 : {1, 2, 3, 4}
+            Corner of *bbox1* and *bbox2* to draw the line. Valid values are::
 
                 'upper right'  : 1,
                 'upper left'   : 2,
                 'lower left'   : 3,
                 'lower right'  : 4
 
-        loc2 : {1, 2, 3, 4}, optional
-            Corner of *bbox2* to draw the line. If None, defaults to *loc1*.
-            Valid values are::
-
-                'upper right'  : 1,
-                'upper left'   : 2,
-                'lower left'   : 3,
-                'lower right'  : 4
+            *loc2* is optional and defaults to *loc1*.
 
         **kwargs
             Patch properties for the line drawn. Valid arguments include:
-            %(Patch)s
+
+            %(Patch:kwdoc)s
         """
         if "transform" in kwargs:
             raise ValueError("transform should not be set")
 
         kwargs["transform"] = IdentityTransform()
         if 'fill' in kwargs:
-            Patch.__init__(self, **kwargs)
+            super().__init__(**kwargs)
         else:
             fill = bool({'fc', 'facecolor', 'color'}.intersection(kwargs))
-            Patch.__init__(self, fill=fill, **kwargs)
+            super().__init__(fill=fill, **kwargs)
         self.bbox1 = bbox1
         self.bbox2 = bbox2
         self.loc1 = loc1
@@ -317,7 +237,7 @@ class BboxConnector(Patch):
 
 
 class BboxConnectorPatch(BboxConnector):
-    @docstring.dedent_interpd
+    @_docstring.dedent_interpd
     def __init__(self, bbox1, bbox2, loc1a, loc2a, loc1b, loc2b, **kwargs):
         """
         Connect two bboxes with a quadrilateral.
@@ -329,21 +249,13 @@ class BboxConnectorPatch(BboxConnector):
 
         Parameters
         ----------
-        bbox1, bbox2 : `matplotlib.transforms.Bbox`
+        bbox1, bbox2 : `~matplotlib.transforms.Bbox`
             Bounding boxes to connect.
 
-        loc1a, loc2a : {1, 2, 3, 4}
-            Corners of *bbox1* and *bbox2* to draw the first line.
-            Valid values are::
-
-                'upper right'  : 1,
-                'upper left'   : 2,
-                'lower left'   : 3,
-                'lower right'  : 4
-
-        loc1b, loc2b : {1, 2, 3, 4}
-            Corners of *bbox1* and *bbox2* to draw the second line.
-            Valid values are::
+        loc1a, loc2a, loc1b, loc2b : {1, 2, 3, 4}
+            The first line connects corners *loc1a* of *bbox1* and *loc2a* of
+            *bbox2*; the second line connects corners *loc1b* of *bbox1* and
+            *loc2b* of *bbox2*.  Valid values are::
 
                 'upper right'  : 1,
                 'upper left'   : 2,
@@ -352,11 +264,12 @@ class BboxConnectorPatch(BboxConnector):
 
         **kwargs
             Patch properties for the line drawn:
-            %(Patch)s
+
+            %(Patch:kwdoc)s
         """
         if "transform" in kwargs:
             raise ValueError("transform should not be set")
-        BboxConnector.__init__(self, bbox1, bbox2, loc1a, loc2a, **kwargs)
+        super().__init__(bbox1, bbox2, loc1a, loc2a, **kwargs)
         self.loc1b = loc1b
         self.loc2b = loc2b
 
@@ -370,16 +283,15 @@ class BboxConnectorPatch(BboxConnector):
 
 
 def _add_inset_axes(parent_axes, inset_axes):
-    """Helper function to add an inset axes and disable navigation in it"""
+    """Helper function to add an inset axes and disable navigation in it."""
     parent_axes.figure.add_axes(inset_axes)
     inset_axes.set_navigate(False)
 
 
-@docstring.dedent_interpd
+@_docstring.dedent_interpd
 def inset_axes(parent_axes, width, height, loc='upper right',
                bbox_to_anchor=None, bbox_transform=None,
-               axes_class=None,
-               axes_kwargs=None,
+               axes_class=None, axes_kwargs=None,
                borderpad=0.5):
     """
     Create an inset axes with a given width and height.
@@ -387,7 +299,7 @@ def inset_axes(parent_axes, width, height, loc='upper right',
     Both sizes used can be specified either in inches or percentage.
     For example,::
 
-        inset_axes(parent_axes, width='40%%', height='30%%', loc=3)
+        inset_axes(parent_axes, width='40%%', height='30%%', loc='lower left')
 
     creates in inset axes in the lower left corner of *parent_axes* which spans
     over 30%% in height and 40%% in width of the *parent_axes*. Since the usage
@@ -424,24 +336,18 @@ def inset_axes(parent_axes, width, height, loc='upper right',
         the size in inches, e.g. *width=1.3*. If a string is provided, it is
         the size in relative units, e.g. *width='40%%'*. By default, i.e. if
         neither *bbox_to_anchor* nor *bbox_transform* are specified, those
-        are relative to the parent_axes. Otherwise they are to be understood
+        are relative to the parent_axes. Otherwise, they are to be understood
         relative to the bounding box provided via *bbox_to_anchor*.
 
-    loc : int or string, optional, default to 1
-        Location to place the inset axes. The valid locations are::
+    loc : str, default: 'upper right'
+        Location to place the inset axes.  Valid locations are
+        'upper left', 'upper center', 'upper right',
+        'center left', 'center', 'center right',
+        'lower left', 'lower center', 'lower right'.
+        For backward compatibility, numeric values are accepted as well.
+        See the parameter *loc* of `.Legend` for details.
 
-            'upper right'  : 1,
-            'upper left'   : 2,
-            'lower left'   : 3,
-            'lower right'  : 4,
-            'right'        : 5,
-            'center left'  : 6,
-            'center right' : 7,
-            'lower center' : 8,
-            'upper center' : 9,
-            'center'       : 10
-
-    bbox_to_anchor : tuple or `matplotlib.transforms.BboxBase`, optional
+    bbox_to_anchor : tuple or `~matplotlib.transforms.BboxBase`, optional
         Bbox that the inset axes will be anchored to. If None,
         a tuple of (0, 0, 1, 1) is used if *bbox_transform* is set
         to *parent_axes.transAxes* or *parent_axes.figure.transFigure*.
@@ -455,7 +361,7 @@ def inset_axes(parent_axes, width, height, loc='upper right',
         a *bbox_transform*. This might often be the axes transform
         *parent_axes.transAxes*.
 
-    bbox_transform : `matplotlib.transforms.Transform`, optional
+    bbox_transform : `~matplotlib.transforms.Transform`, optional
         Transformation for the bbox that contains the inset axes.
         If None, a `.transforms.IdentityTransform` is used. The value
         of *bbox_to_anchor* (or the return value of its get_points method)
@@ -464,53 +370,50 @@ def inset_axes(parent_axes, width, height, loc='upper right',
         You may provide *bbox_to_anchor* in some normalized coordinate,
         and give an appropriate transform (e.g., *parent_axes.transAxes*).
 
-    axes_class : `matplotlib.axes.Axes` type, optional
-        If specified, the inset axes created will be created with this class's
-        constructor.
+    axes_class : `~matplotlib.axes.Axes` type, default: `.HostAxes`
+        The type of the newly created inset axes.
 
     axes_kwargs : dict, optional
-        Keyworded arguments to pass to the constructor of the inset axes.
+        Keyword arguments to pass to the constructor of the inset axes.
         Valid arguments include:
-        %(Axes)s
 
-    borderpad : float, optional
-        Padding between inset axes and the bbox_to_anchor. Defaults to 0.5.
+        %(Axes:kwdoc)s
+
+    borderpad : float, default: 0.5
+        Padding between inset axes and the bbox_to_anchor.
         The units are axes font size, i.e. for a default font size of 10 points
         *borderpad = 0.5* is equivalent to a padding of 5 points.
 
     Returns
     -------
-    inset_axes : `axes_class`
+    inset_axes : *axes_class*
         Inset axes object created.
     """
 
     if axes_class is None:
         axes_class = HostAxes
-
     if axes_kwargs is None:
-        inset_axes = axes_class(parent_axes.figure, parent_axes.get_position())
-    else:
-        inset_axes = axes_class(parent_axes.figure, parent_axes.get_position(),
-                                **axes_kwargs)
+        axes_kwargs = {}
+    inset_axes = axes_class(parent_axes.figure, parent_axes.get_position(),
+                            **axes_kwargs)
 
     if bbox_transform in [parent_axes.transAxes,
                           parent_axes.figure.transFigure]:
         if bbox_to_anchor is None:
-            cbook._warn_external("Using the axes or figure transform "
-                                 "requires a bounding box in the respective "
-                                 "coordinates. "
-                                 "Using bbox_to_anchor=(0,0,1,1) now.")
+            _api.warn_external("Using the axes or figure transform requires a "
+                               "bounding box in the respective coordinates. "
+                               "Using bbox_to_anchor=(0, 0, 1, 1) now.")
             bbox_to_anchor = (0, 0, 1, 1)
 
     if bbox_to_anchor is None:
         bbox_to_anchor = parent_axes.bbox
 
-    if isinstance(bbox_to_anchor, tuple) and \
-        (isinstance(width, str) or isinstance(height, str)):
+    if (isinstance(bbox_to_anchor, tuple) and
+            (isinstance(width, str) or isinstance(height, str))):
         if len(bbox_to_anchor) != 4:
             raise ValueError("Using relative units for width or height "
                              "requires to provide a 4-tuple or a "
-                             "`BBox` instance to `bbox_to_anchor.")
+                             "`Bbox` instance to `bbox_to_anchor.")
 
     axes_locator = AnchoredSizeLocator(bbox_to_anchor,
                                        width, height,
@@ -525,11 +428,10 @@ def inset_axes(parent_axes, width, height, loc='upper right',
     return inset_axes
 
 
-@docstring.dedent_interpd
+@_docstring.dedent_interpd
 def zoomed_inset_axes(parent_axes, zoom, loc='upper right',
                       bbox_to_anchor=None, bbox_transform=None,
-                      axes_class=None,
-                      axes_kwargs=None,
+                      axes_class=None, axes_kwargs=None,
                       borderpad=0.5):
     """
     Create an anchored inset axes by scaling a parent axes. For usage, also see
@@ -537,29 +439,23 @@ def zoomed_inset_axes(parent_axes, zoom, loc='upper right',
 
     Parameters
     ----------
-    parent_axes : `matplotlib.axes.Axes`
+    parent_axes : `~matplotlib.axes.Axes`
         Axes to place the inset axes.
 
     zoom : float
-        Scaling factor of the data axes. *zoom* > 1 will enlargen the
+        Scaling factor of the data axes. *zoom* > 1 will enlarge the
         coordinates (i.e., "zoomed in"), while *zoom* < 1 will shrink the
         coordinates (i.e., "zoomed out").
 
-    loc : int or string, optional, default to 1
-        Location to place the inset axes. The valid locations are::
+    loc : str, default: 'upper right'
+        Location to place the inset axes.  Valid locations are
+        'upper left', 'upper center', 'upper right',
+        'center left', 'center', 'center right',
+        'lower left', 'lower center', 'lower right'.
+        For backward compatibility, numeric values are accepted as well.
+        See the parameter *loc* of `.Legend` for details.
 
-            'upper right'  : 1,
-            'upper left'   : 2,
-            'lower left'   : 3,
-            'lower right'  : 4,
-            'right'        : 5,
-            'center left'  : 6,
-            'center right' : 7,
-            'lower center' : 8,
-            'upper center' : 9,
-            'center'       : 10
-
-    bbox_to_anchor : tuple or `matplotlib.transforms.BboxBase`, optional
+    bbox_to_anchor : tuple or `~matplotlib.transforms.BboxBase`, optional
         Bbox that the inset axes will be anchored to. If None,
         *parent_axes.bbox* is used. If a tuple, can be either
         [left, bottom, width, height], or [left, bottom].
@@ -570,7 +466,7 @@ def zoomed_inset_axes(parent_axes, zoom, loc='upper right',
         also specify a *bbox_transform*. This might often be the axes transform
         *parent_axes.transAxes*.
 
-    bbox_transform : `matplotlib.transforms.Transform`, optional
+    bbox_transform : `~matplotlib.transforms.Transform`, optional
         Transformation for the bbox that contains the inset axes.
         If None, a `.transforms.IdentityTransform` is used (i.e. pixel
         coordinates). This is useful when not providing any argument to
@@ -581,34 +477,32 @@ def zoomed_inset_axes(parent_axes, zoom, loc='upper right',
         *bbox_to_anchor* will use *parent_axes.bbox*, the units of which are
         in display (pixel) coordinates.
 
-    axes_class : `matplotlib.axes.Axes` type, optional
-        If specified, the inset axes created will be created with this class's
-        constructor.
+    axes_class : `~matplotlib.axes.Axes` type, default: `.HostAxes`
+        The type of the newly created inset axes.
 
     axes_kwargs : dict, optional
-        Keyworded arguments to pass to the constructor of the inset axes.
+        Keyword arguments to pass to the constructor of the inset axes.
         Valid arguments include:
-        %(Axes)s
 
-    borderpad : float, optional
-        Padding between inset axes and the bbox_to_anchor. Defaults to 0.5.
+        %(Axes:kwdoc)s
+
+    borderpad : float, default: 0.5
+        Padding between inset axes and the bbox_to_anchor.
         The units are axes font size, i.e. for a default font size of 10 points
         *borderpad = 0.5* is equivalent to a padding of 5 points.
 
     Returns
     -------
-    inset_axes : `axes_class`
+    inset_axes : *axes_class*
         Inset axes object created.
     """
 
     if axes_class is None:
         axes_class = HostAxes
-
     if axes_kwargs is None:
-        inset_axes = axes_class(parent_axes.figure, parent_axes.get_position())
-    else:
-        inset_axes = axes_class(parent_axes.figure, parent_axes.get_position(),
-                                **axes_kwargs)
+        axes_kwargs = {}
+    inset_axes = axes_class(parent_axes.figure, parent_axes.get_position(),
+                            **axes_kwargs)
 
     axes_locator = AnchoredZoomLocator(parent_axes, zoom=zoom, loc=loc,
                                        bbox_to_anchor=bbox_to_anchor,
@@ -621,7 +515,23 @@ def zoomed_inset_axes(parent_axes, zoom, loc='upper right',
     return inset_axes
 
 
-@docstring.dedent_interpd
+class _TransformedBboxWithCallback(TransformedBbox):
+    """
+    Variant of `.TransformBbox` which calls *callback* before returning points.
+
+    Used by `.mark_inset` to unstale the parent axes' viewlim as needed.
+    """
+
+    def __init__(self, *args, callback, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._callback = callback
+
+    def get_points(self):
+        self._callback()
+        return super().get_points()
+
+
+@_docstring.dedent_interpd
 def mark_inset(parent_axes, inset_axes, loc1, loc2, **kwargs):
     """
     Draw a box to mark the location of an area represented by an inset axes.
@@ -632,10 +542,10 @@ def mark_inset(parent_axes, inset_axes, loc1, loc2, **kwargs):
 
     Parameters
     ----------
-    parent_axes : `matplotlib.axes.Axes`
+    parent_axes : `~matplotlib.axes.Axes`
         Axes which contains the area of the inset axes.
 
-    inset_axes : `matplotlib.axes.Axes`
+    inset_axes : `~matplotlib.axes.Axes`
         The inset axes.
 
     loc1, loc2 : {1, 2, 3, 4}
@@ -644,17 +554,20 @@ def mark_inset(parent_axes, inset_axes, loc1, loc2, **kwargs):
 
     **kwargs
         Patch properties for the lines and box drawn:
-        %(Patch)s
+
+        %(Patch:kwdoc)s
 
     Returns
     -------
-    pp : `matplotlib.patches.Patch`
+    pp : `~matplotlib.patches.Patch`
         The patch drawn to represent the area of the inset axes.
 
-    p1, p2 : `matplotlib.patches.Patch`
+    p1, p2 : `~matplotlib.patches.Patch`
         The patches connecting two corners of the inset axes and its area.
     """
-    rect = TransformedBbox(inset_axes.viewLim, parent_axes.transData)
+    rect = _TransformedBboxWithCallback(
+        inset_axes.viewLim, parent_axes.transData,
+        callback=parent_axes._unstale_viewLim)
 
     if 'fill' in kwargs:
         pp = BboxPatch(rect, **kwargs)
