@@ -5,38 +5,33 @@ Poly Editor
 
 This is an example to show how to build cross-GUI applications using
 Matplotlib event handling to interact with objects on the canvas.
+
+.. note::
+    This example exercises the interactive capabilities of Matplotlib, and this
+    will not appear in the static documentation. Please run this code on your
+    machine to see the interactivity.
+
+    You can copy and paste individual parts, or download the entire example
+    using the link at the bottom of the page.
 """
+
 import numpy as np
 from matplotlib.lines import Line2D
 from matplotlib.artist import Artist
 
 
-def dist(x, y):
-    """
-    Return the distance between two points.
-    """
-    d = x - y
-    return np.sqrt(np.dot(d, d))
-
-
 def dist_point_to_segment(p, s0, s1):
     """
-    Get the distance of a point to a segment.
-      *p*, *s0*, *s1* are *xy* sequences
-    This algorithm from
-    http://geomalgorithms.com/a02-_lines.html
+    Get the distance from the point *p* to the segment (*s0*, *s1*), where
+    *p*, *s0*, *s1* are ``[x, y]`` arrays.
     """
-    v = s1 - s0
-    w = p - s0
-    c1 = np.dot(w, v)
-    if c1 <= 0:
-        return dist(p, s0)
-    c2 = np.dot(v, v)
-    if c2 <= c1:
-        return dist(p, s1)
-    b = c1 / c2
-    pb = s0 + b * v
-    return dist(p, pb)
+    s01 = s1 - s0
+    s0p = p - s0
+    if (s01 == 0).all():
+        return np.hypot(*s0p)
+    # Project onto segment, without going past segment ends.
+    p1 = s0 + np.clip((s0p @ s01) / (s01 @ s01), 0, 1) * s01
+    return np.hypot(*(p - p1))
 
 
 class PolygonInteractor:
@@ -75,14 +70,14 @@ class PolygonInteractor:
         self.cid = self.poly.add_callback(self.poly_changed)
         self._ind = None  # the active vert
 
-        canvas.mpl_connect('draw_event', self.draw_callback)
-        canvas.mpl_connect('button_press_event', self.button_press_callback)
-        canvas.mpl_connect('key_press_event', self.key_press_callback)
-        canvas.mpl_connect('button_release_event', self.button_release_callback)
-        canvas.mpl_connect('motion_notify_event', self.motion_notify_callback)
+        canvas.mpl_connect('draw_event', self.on_draw)
+        canvas.mpl_connect('button_press_event', self.on_button_press)
+        canvas.mpl_connect('key_press_event', self.on_key_press)
+        canvas.mpl_connect('button_release_event', self.on_button_release)
+        canvas.mpl_connect('motion_notify_event', self.on_mouse_move)
         self.canvas = canvas
 
-    def draw_callback(self, event):
+    def on_draw(self, event):
         self.background = self.canvas.copy_from_bbox(self.ax.bbox)
         self.ax.draw_artist(self.poly)
         self.ax.draw_artist(self.line)
@@ -114,7 +109,7 @@ class PolygonInteractor:
 
         return ind
 
-    def button_press_callback(self, event):
+    def on_button_press(self, event):
         """Callback for mouse button presses."""
         if not self.showverts:
             return
@@ -124,7 +119,7 @@ class PolygonInteractor:
             return
         self._ind = self.get_ind_under_point(event)
 
-    def button_release_callback(self, event):
+    def on_button_release(self, event):
         """Callback for mouse button releases."""
         if not self.showverts:
             return
@@ -132,7 +127,7 @@ class PolygonInteractor:
             return
         self._ind = None
 
-    def key_press_callback(self, event):
+    def on_key_press(self, event):
         """Callback for key presses."""
         if not event.inaxes:
             return
@@ -164,7 +159,7 @@ class PolygonInteractor:
         if self.line.stale:
             self.canvas.draw_idle()
 
-    def motion_notify_callback(self, event):
+    def on_mouse_move(self, event):
         """Callback for mouse movements."""
         if not self.showverts:
             return
