@@ -14,8 +14,8 @@ import numpy as np
 #
 # Basic usage
 # -----------
-# The parameters *y1* and *y2* can be a scalar, indicating a horizontal
-# boundary a  the given y-values. If only *y1* is given, *y2* defaults to 0.
+# The parameters *y1* and *y2* can be scalars, indicating a horizontal
+# boundary at the given y-values. If only *y1* is given, *y2* defaults to 0.
 
 x = np.arange(0.0, 2, 0.01)
 y1 = np.sin(2 * np.pi * x)
@@ -52,7 +52,7 @@ N = 21
 x = np.linspace(0, 10, 11)
 y = [3.9, 4.4, 10.8, 10.3, 11.2, 13.1, 14.1,  9.9, 13.9, 15.1, 12.5]
 
-# fit a linear curve an estimate its y-values and their error.
+# fit a linear curve and estimate its y-values and their error.
 a, b = np.polyfit(x, y, deg=1)
 y_est = a * x + b
 y_err = x.std() * np.sqrt(1/len(x) +
@@ -114,7 +114,7 @@ fig.tight_layout()
 # ------------------------------------------------------------
 # The same selection mechanism can be applied to fill the full vertical height
 # of the axes. To be independent of y-limits, we add a transform that
-# interprets the x-values in data coorindates and the y-values in axes
+# interprets the x-values in data coordinates and the y-values in axes
 # coordinates.
 #
 # The following example marks the regions in which the y-data are above a
@@ -132,15 +132,10 @@ ax.fill_between(x, 0, 1, where=y > threshold,
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods and classes is shown
-# in this example:
-
-import matplotlib
-matplotlib.axes.Axes.fill_between
-matplotlib.pyplot.fill_between
-matplotlib.axes.Axes.get_xaxis_transform
+#    - `matplotlib.axes.Axes.fill_between` / `matplotlib.pyplot.fill_between`
+#    - `matplotlib.axes.Axes.get_xaxis_transform`
