@@ -12,7 +12,6 @@ of how this can be accomplished and visualized with Matplotlib.
 import matplotlib.pyplot as plt
 import numpy as np
 import matplotlib.mlab as mlab
-import matplotlib.gridspec as gridspec
 
 # Fixing random state for reproducibility
 np.random.seed(19680801)
@@ -26,10 +25,9 @@ cnse = np.convolve(nse, r) * dt
 cnse = cnse[:len(t)]
 s = 0.1 * np.sin(2 * np.pi * t) + cnse
 
-plt.subplot(211)
-plt.plot(t, s)
-plt.subplot(212)
-plt.psd(s, 512, 1 / dt)
+fig, (ax0, ax1) = plt.subplots(2, 1)
+ax0.plot(t, s)
+ax1.psd(s, 512, 1 / dt)
 
 plt.show()
 
@@ -45,7 +43,7 @@ plt.show()
 #     s = 0.1*sin(2*pi*t) + cnse;
 #
 #     subplot(211)
-#     plot(t,s)
+#     plot(t, s)
 #     subplot(212)
 #     psd(s, 512, 1/dt)
 #
@@ -59,39 +57,44 @@ y = 10. * np.sin(2 * np.pi * 4 * t) + 5. * np.sin(2 * np.pi * 4.25 * t)
 y = y + np.random.randn(*t.shape)
 
 # Plot the raw time series
-fig = plt.figure(constrained_layout=True)
-gs = gridspec.GridSpec(2, 3, figure=fig)
-ax = fig.add_subplot(gs[0, :])
-ax.plot(t, y)
-ax.set_xlabel('time [s]')
-ax.set_ylabel('signal')
+fig, axs = plt.subplot_mosaic([
+    ['signal', 'signal', 'signal'],
+    ['zero padding', 'block size', 'overlap'],
+], layout='constrained')
+
+axs['signal'].plot(t, y)
+axs['signal'].set_xlabel('time [s]')
+axs['signal'].set_ylabel('signal')
 
 # Plot the PSD with different amounts of zero padding. This uses the entire
 # time series at once
-ax2 = fig.add_subplot(gs[1, 0])
-ax2.psd(y, NFFT=len(t), pad_to=len(t), Fs=fs)
-ax2.psd(y, NFFT=len(t), pad_to=len(t) * 2, Fs=fs)
-ax2.psd(y, NFFT=len(t), pad_to=len(t) * 4, Fs=fs)
-plt.title('zero padding')
+axs['zero padding'].psd(y, NFFT=len(t), pad_to=len(t), Fs=fs)
+axs['zero padding'].psd(y, NFFT=len(t), pad_to=len(t) * 2, Fs=fs)
+axs['zero padding'].psd(y, NFFT=len(t), pad_to=len(t) * 4, Fs=fs)
 
 # Plot the PSD with different block sizes, Zero pad to the length of the
 # original data sequence.
-ax3 = fig.add_subplot(gs[1, 1], sharex=ax2, sharey=ax2)
-ax3.psd(y, NFFT=len(t), pad_to=len(t), Fs=fs)
-ax3.psd(y, NFFT=len(t) // 2, pad_to=len(t), Fs=fs)
-ax3.psd(y, NFFT=len(t) // 4, pad_to=len(t), Fs=fs)
-ax3.set_ylabel('')
-plt.title('block size')
+axs['block size'].psd(y, NFFT=len(t), pad_to=len(t), Fs=fs)
+axs['block size'].psd(y, NFFT=len(t) // 2, pad_to=len(t), Fs=fs)
+axs['block size'].psd(y, NFFT=len(t) // 4, pad_to=len(t), Fs=fs)
+axs['block size'].set_ylabel('')
 
 # Plot the PSD with different amounts of overlap between blocks
-ax4 = fig.add_subplot(gs[1, 2], sharex=ax2, sharey=ax2)
-ax4.psd(y, NFFT=len(t) // 2, pad_to=len(t), noverlap=0, Fs=fs)
-ax4.psd(y, NFFT=len(t) // 2, pad_to=len(t),
-        noverlap=int(0.05 * len(t) / 2.), Fs=fs)
-ax4.psd(y, NFFT=len(t) // 2, pad_to=len(t),
-        noverlap=int(0.2 * len(t) / 2.), Fs=fs)
-ax4.set_ylabel('')
-plt.title('overlap')
+axs['overlap'].psd(y, NFFT=len(t) // 2, pad_to=len(t), noverlap=0, Fs=fs)
+axs['overlap'].psd(y, NFFT=len(t) // 2, pad_to=len(t),
+                   noverlap=int(0.025 * len(t)), Fs=fs)
+axs['overlap'].psd(y, NFFT=len(t) // 2, pad_to=len(t),
+                   noverlap=int(0.1 * len(t)), Fs=fs)
+axs['overlap'].set_ylabel('')
+axs['overlap'].set_title('overlap')
+
+for title, ax in axs.items():
+    if title == 'signal':
+        continue
+
+    ax.set_title(title)
+    ax.sharex(axs['zero padding'])
+    ax.sharey(axs['zero padding'])
 
 plt.show()
 
@@ -108,7 +111,7 @@ f = np.array([150, 140]).reshape(-1, 1)
 xn = (A * np.sin(2 * np.pi * f * t)).sum(axis=0)
 xn += 5 * np.random.randn(*t.shape)
 
-fig, (ax0, ax1) = plt.subplots(ncols=2, constrained_layout=True)
+fig, (ax0, ax1) = plt.subplots(ncols=2, layout='constrained')
 
 yticks = np.arange(-50, 30, 10)
 yrange = (yticks[0], yticks[-1])
@@ -148,7 +151,7 @@ A = np.array([2, 8]).reshape(-1, 1)
 f = np.array([150, 140]).reshape(-1, 1)
 xn = (A * np.exp(2j * np.pi * f * t)).sum(axis=0) + 5 * prng.randn(*t.shape)
 
-fig, (ax0, ax1) = plt.subplots(ncols=2, constrained_layout=True)
+fig, (ax0, ax1) = plt.subplots(ncols=2, layout='constrained')
 
 yticks = np.arange(-50, 30, 10)
 yrange = (yticks[0], yticks[-1])
