@@ -1,15 +1,18 @@
 """
 ==============
-SVG Filter Pie
+SVG filter pie
 ==============
 
-Demonstrate SVG filtering effects which might be used with mpl.
+Demonstrate SVG filtering effects which might be used with Matplotlib.
 The pie chart drawing code is borrowed from pie_demo.py
 
-Note that the filtering effects are only effective if your svg renderer
+Note that the filtering effects are only effective if your SVG renderer
 support it.
 """
 
+import io
+import xml.etree.ElementTree as ET
+
 import matplotlib.pyplot as plt
 from matplotlib.patches import Shadow
 
@@ -22,8 +25,8 @@ fracs = [15, 30, 45, 10]
 
 explode = (0, 0.05, 0, 0)
 
-# We want to draw the shadow for each pie but we will not use "shadow"
-# option as it does'n save the references to the shadow patches.
+# We want to draw the shadow for each pie, but we will not use "shadow"
+# option as it doesn't save the references to the shadow patches.
 pies = ax.pie(fracs, explode=explode, labels=labels, autopct='%1.1f%%')
 
 for w in pies[0]:
@@ -42,35 +45,34 @@ for w in pies[0]:
 
 
 # save
-from io import BytesIO
-f = BytesIO()
+f = io.BytesIO()
 plt.savefig(f, format="svg")
 
-import xml.etree.ElementTree as ET
 
-
-# filter definition for shadow using a gaussian blur
-# and lightening effect.
-# The lightening filter is copied from http://www.w3.org/TR/SVG/filters.html
+# Filter definition for shadow using a gaussian blur and lighting effect.
+# The lighting filter is copied from http://www.w3.org/TR/SVG/filters.html
 
 # I tested it with Inkscape and Firefox3. "Gaussian blur" is supported
-# in both, but the lightening effect only in the Inkscape. Also note
+# in both, but the lighting effect only in Inkscape. Also note
 # that, Inkscape's exporting also may not support it.
 
 filter_def = """
-  <defs xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'>
+  <defs xmlns='http://www.w3.org/2000/svg'
+        xmlns:xlink='http://www.w3.org/1999/xlink'>
     <filter id='dropshadow' height='1.2' width='1.2'>
       <feGaussianBlur result='blur' stdDeviation='2'/>
     </filter>
 
-    <filter id='MyFilter' filterUnits='objectBoundingBox' x='0' y='0' width='1' height='1'>
+    <filter id='MyFilter' filterUnits='objectBoundingBox'
+            x='0' y='0' width='1' height='1'>
       <feGaussianBlur in='SourceAlpha' stdDeviation='4%' result='blur'/>
       <feOffset in='blur' dx='4%' dy='4%' result='offsetBlur'/>
       <feSpecularLighting in='blur' surfaceScale='5' specularConstant='.75'
            specularExponent='20' lighting-color='#bbbbbb' result='specOut'>
         <fePointLight x='-5000%' y='-10000%' z='20000%'/>
       </feSpecularLighting>
-      <feComposite in='specOut' in2='SourceAlpha' operator='in' result='specOut'/>
+      <feComposite in='specOut' in2='SourceAlpha'
+                   operator='in' result='specOut'/>
       <feComposite in='SourceGraphic' in2='specOut' operator='arithmetic'
     k1='0' k2='1' k3='1' k4='0'/>
     </filter>
@@ -91,5 +93,5 @@ for i, pie_name in enumerate(labels):
     shadow.set("filter", 'url(#dropshadow)')
 
 fn = "svg_filter_pie.svg"
-print("Saving '%s'" % fn)
+print(f"Saving '{fn}'")
 ET.ElementTree(tree).write(fn)
