@@ -8,11 +8,9 @@ A basic demo of how to plot 3D bars with and without shading.
 
 import numpy as np
 import matplotlib.pyplot as plt
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
 
 
-# setup the figure and axes
+# set up the figure and axes
 fig = plt.figure(figsize=(8, 3))
 ax1 = fig.add_subplot(121, projection='3d')
 ax2 = fig.add_subplot(122, projection='3d')
