@@ -1,12 +1,12 @@
 """
-==========================
-Rotating 3D wireframe plot
-==========================
+===========================
+Animate a 3D wireframe plot
+===========================
 
-A very simple 'animation' of a 3D plot.  See also rotate_axes3d_demo.
+A very simple "animation" of a 3D plot.  See also :doc:`rotate_axes3d_sgskip`.
 
 (This example is skipped when building the documentation gallery because it
-intentionally takes a long time to run)
+intentionally takes a long time to run.)
 """
 
 import matplotlib.pyplot as plt
@@ -14,23 +14,15 @@ import numpy as np
 import time
 
 
-def generate(X, Y, phi):
-    '''
-    Generates Z data for the points in the X, Y meshgrid and parameter phi.
-    '''
-    R = 1 - np.sqrt(X**2 + Y**2)
-    return np.cos(2 * np.pi * X + phi) * R
-
-
 fig = plt.figure()
-ax = fig.add_subplot(111, projection='3d')
+ax = fig.add_subplot(projection='3d')
 
 # Make the X, Y meshgrid.
 xs = np.linspace(-1, 1, 50)
 ys = np.linspace(-1, 1, 50)
 X, Y = np.meshgrid(xs, ys)
 
-# Set the z axis limits so they aren't recalculated each frame.
+# Set the z axis limits, so they aren't recalculated each frame.
 ax.set_zlim(-1, 1)
 
 # Begin plotting.
@@ -39,10 +31,10 @@ tstart = time.time()
 for phi in np.linspace(0, 180. / np.pi, 100):
     # If a line collection is already remove it before drawing.
     if wframe:
-        ax.collections.remove(wframe)
-
+        wframe.remove()
+    # Generate data.
+    Z = np.cos(2 * np.pi * X + phi) * (1 - np.hypot(X, Y))
     # Plot the new wireframe and pause briefly before continuing.
-    Z = generate(X, Y, phi)
     wframe = ax.plot_wireframe(X, Y, Z, rstride=2, cstride=2)
     plt.pause(.001)
 
